# import geopandas as gpd
import numpy as np
from .tspline import tspline


class centerline:
    """
    class to take a centerline as a shapefile and create a tension spline to be used
    with inherited class curvilinear grid
    """

    def __init__(self, center_shp, nx, tension):
        self.center_shp = center_shp
        self.gpdata = center_shp
        self.x = np.empty(0, dtype=np.double)
        self.y = np.empty(0, dtype=np.double)
        self.tension = 0.5
        self.numclpts = 0
        self.numInterpPts = nx
        self.si = np.empty(0, dtype=np.double)
        self.temp = np.empty(0, dtype=np.double)
        self.yp = np.empty(0, dtype=np.double)
        self.xo_interp = np.empty(0, dtype=np.double)
        self.yo_interp = np.empty(0, dtype=np.double)
        self.phi_interp = np.empty(0, dtype=np.double)
        self.r_interp = np.empty(0, dtype=np.double)
        self.stot = np.empty(0, dtype=np.double)
        self.sout = np.empty(0, dtype=np.double)
        self.__initialize()
        self.__getspline(nx, self.tension)

    def __initialize(self):
        tx = []
        ty = []
        for index, row in self.gpdata.iterrows():
            for pt in list(row['geometry'].coords):
                # print(pt, type(pt))
                tx.append(pt[0])
                ty.append(pt[1])
        self.x = np.array(tx)
        self.y = np.array(ty)
        self.numclpts = self.x.size

    # def description(self):
    #     return "{} used the shapfile {}".format("centerline", self.center_shp)

    # def getCLShapeFile(self):
    #     return self.center_shp

    def getlength(self):
        return

    def getpoints(self):
        return self.x, self.y

    def getinterppts(self):
        return self.xo_interp, self.yo_interp

    def getinterppts_dyn(self, numinterppts, tension):
        print(tension)
        self.__getspline(numinterppts, tension)
        return self.xo_interp, self.yo_interp

    def getphiinterp(self, index):
        return self.phi_interp[index]

    def __getspline(self, numinterppts, tension):
        self.numInterpPts = numinterppts
        self.tension = tension
        self.xo_interp = np.zeros(self.numInterpPts)
        self.yo_interp = np.zeros(self.numInterpPts)
        self.phi_interp = np.zeros(self.numInterpPts)
        self.r_interp = np.zeros(self.numInterpPts)
        self.stot = np.zeros(self.numInterpPts)
        self.sout = np.zeros(self.numInterpPts)

        self.si = np.zeros(self.numclpts)
        self.temp = np.zeros(self.numclpts)
        self.yp = np.zeros(self.numclpts)

        for i in range(0, self.numclpts):
            if i == 0:
                self.si[i] = 0.0
            else:
                ds = np.power((np.power((self.x[i] - self.x[i - 1]), 2) +
                               np.power((self.y[i] - self.y[i - 1]), 2)), 0.5)
                self.si[i] = self.si[i-1] + ds

        self.stot = self.si[self.numclpts - 1]
        for i in range(0, self.numInterpPts):
            self.sout[i] = i * self.stot / (self.numInterpPts - 1)
            # if i == 0:
            #     nsInc = self.stot / (self.numInterpPts - 1)
        if self.numclpts < 3:
            self.yp = np.zeros(3)
            self.temp = np.zeros(3)
            sitmp = np.zeros(3)
            sitmp = np.append(sitmp, [self.si[0]])
            sitmp = np.append(sitmp, [self.si[1] / 2])
            sitmp = np.append(sitmp, self.si[1])

            txctmp = np.zeros(3)
            txctmp = np.append(txctmp, self.x[0])
            txctmp = np.append(txctmp, self.x[0] + (self.x[1] - self.x[0]) / 2.)
            txctmp = np.append(txctmp, self.x[1])

            tyctmp = np.zeros(3)
            tyctmp = np.append(tyctmp, self.y[0])
            tyctmp = np.append(tyctmp, self.y[0] + (self.y[1] - self.y[0]) / 2.)
            tyctmp = np.append(tyctmp, self.y[1])

            tspline(sitmp, txctmp, 3, self.sout, self.xo_interp,
                    self.numInterpPts, self.tension, self.yp, self.temp)
            tspline(sitmp, tyctmp, 3, self.sout, self.yo_interp,
                    self.numInterpPts, self.tension, self.yp, self.temp)
        else:
            tspline(self.si, self.x, self.numclpts, self.sout, self.xo_interp,
                    self.numInterpPts, self.tension, self.yp, self.temp)
            tspline(self.si, self.y, self.numclpts, self.sout, self.yo_interp,
                    self.numInterpPts, self.tension, self.yp, self.temp)
        self.__calcCurvature()

    def __calcCurvature(self):
        for i in range(1, self.numInterpPts):
            dx = self.xo_interp[i] - self.xo_interp[i - 1]
            dy = self.yo_interp[i] - self.yo_interp[i - 1]
            if dx == 0.:
                if dy > 0.:
                    self.phi_interp[i] = np.pi/2.
                elif dy < 0.:
                    self.phi_interp[i] = -1.*np.pi/2.
            else:
                self.phi_interp[i] = np.arctan2(dy, dx)
        self.phi_interp[0] = (2. * self.phi_interp[1]) - self.phi_interp[2]
        scals = self.stot/(self.numInterpPts - 1)
        for i in range(1, self.numInterpPts):
            dx = self.xo_interp[i] - self.xo_interp[i - 1]
            dphi = np.fabs(self.phi_interp[i]) - np.fabs(self.phi_interp[i - 1])
            if dphi <= 0.0001:
                self.r_interp[i] = 100000000.
            else:
                self.r_interp[i] = scals/dphi



import pytest

from pynhd import NLDI
from shapely.geometry import Point
from numpy.testing import assert_allclose
from numpy import array
@pytest.mark.parametrize(
    'gage, loc, comid',
    [
        ("USGS-06888500", [(-10705502.110, 4730946.304)], '3643688'),
        ("USGS-06721000", [(-11668351.314, 4882827.631)], '225621'),
        ("USGS-06759500", [(-11555095.784, 4905023.218)], '3561878')
    ]
)
def test_nldi(gage, loc, comid):
    locarray =array(loc)
    gageloc = NLDI().getfeature_byid("nwissite", gage).to_crs('epsg:3857')
    cid = gageloc.comid.values.astype(str)
    strmseg_loc = NLDI().getfeature_byid("comid", cid[0]).to_crs('epsg:3857')
    print(strmseg_loc.comid[0])
    assert(strmseg_loc.comid[0] == comid)
    gageloc_array = array([(gageloc.geometry[0].x, gageloc.geometry[0].y)])
    assert_allclose(gageloc_array, locarray, rtol=0.1 )
    tmp = 0


import pytest

from nldi_el_serv.XSGen import XSGen
from nldi_el_serv.dem_query import query_dems_shape
import py3dep
from pynhd import NLDI
# import xarray as xr
# from matplotlib import pyplot as plt
import json


@pytest.mark.parametrize(
                            'gage, gage_name, res, ny, width',
                            [
                                ("USGS-06888500", 'MILL C NR PAXICO, KS', 3, 100, 200),
                                ("USGS-06721000", 'SOUTH PLATTE RIVER AT FORT LUPTON, CO.', 10, 100, 200),
                                ("USGS-06759500", 'SOUTH PLATTE RIVER AT FORT MORGAN, CO.', 1, 100, 200)
                            ]
                        )
def test_get_gagexs(gage, gage_name, res, ny, width):
    gageloc = NLDI().getfeature_byid("nwissite", gage).to_crs('epsg:3857')
    cid = gageloc.comid.values.astype(str)
    # print(cid, gageloc.comid.values.astype(int)[0])
    strmseg_loc = NLDI().getfeature_byid("comid", cid[0]).to_crs('epsg:3857')
    xs = XSGen(point=gageloc, cl_geom=strmseg_loc, ny=ny, width=width)
    xs_line = xs.get_xs()
    spline = xs.get_strm_seg_spline()
    print(spline)
    t1 = (xs_line.total_bounds) + ((-100., -100., 100., 100.))
    xs_line_geom = xs_line.to_crs('epsg:4326')
    bbox = xs_line_geom.geometry[0].envelope.bounds
    query = query_dems_shape(bbox)
    # print(query)
    query_text = json.dumps(query)
    print(query_text)

    x, y = xs.get_xs_points()
    dem = py3dep.get_map("DEM", tuple(t1), resolution=res, geo_crs="EPSG:3857", crs="epsg:3857")
    dsi = dem.interp(x=('z', x), y=('z', y))
    vals = dsi.values
    if ny % 2 == 0:
        ny += 1

    assert(len(vals) == ny)
    assert(vals.dtype == float)



import numpy as np
from shapely.geometry import LineString, Point
import geopandas as gpd
import pandas as pd


class PathGen:

    def __init__(self, path_geom, ny) -> None:
        # print(path_geom, ny)
        self.path_geom = path_geom
        self.width = self.path_geom.geometry[0].length
        if ny % 2 == 0:
            ny += 1
        self.ny = ny
        self.x = np.zeros(self.ny, dtype=np.double)
        self.y = np.zeros(self.ny, dtype=np.double)
        self.int_path = None
        self._buildpath()

    def _buildpath(self):
        line = self.path_geom.geometry[0]
        spacing = line.length/self.ny
        # print(line, spacing)
        d = 0.0
        index = 0
        while d < self.width and index < self.ny:
            point = line.interpolate(d)
            self.x[index] = point.x
            self.y[index] = point.y
            d += spacing
            index += 1

    def get_xs(self):
        points = gpd.GeoSeries(map(Point, zip(self.x, self.y)))
        ls = LineString((points.to_list()))
        # print(ls)
        d = {0: {'name': 'section-path', 'geometry': ls}}
        df = pd.DataFrame.from_dict(d, orient='index')
        gdf = gpd.GeoDataFrame(df, geometry=df.geometry, crs=self.path_geom.crs)
        return gdf

    def get_xs_points(self):
        return self.x, self.y



"""Main module."""
# from nldi_el_serv.cli import XSAtEndPts
from nldi_el_serv.PathGen import PathGen
from nldi_el_serv.XSGen import XSGen
import requests
# import json
import py3dep
from pynhd import NLDI
# import xarray as xr
# from matplotlib import pyplot as plt
from shapely.geometry import Point, LineString
import geopandas as gpd
import pandas as pd
import numpy as np
# import os.path as path


class HPoint(Point):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    def __hash__(self):
        return hash(tuple(self.coords))


def dataframe_to_geodataframe(df, crs):
    geometry = [HPoint(xy) for xy in zip(df.x, df.y)]
    df = df.drop(['x', 'y'], axis=1)
    gdf = gpd.GeoDataFrame(df, geometry=geometry, crs=crs)
    return gdf


def getXSAtEndPts(path, numpts, crs, file=None, res=10):
    """[summary]

    Args:
        path ([type]): [description]
        numpts ([type]): [description]
        crs ([type]): [description]
        file ([type], optional): [description]. Defaults to None.

    Returns:
        [type]: [description]
    """
    lnst = []
    for pt in path:
        # print(pt[0], pt[1])
        # x.append(pt[0])
        # y.append(pt[1])
        lnst.append(Point(pt[0], pt[1]))
    # ls1 = LineString(lnst)
    # print(ls1)
    d = {'name': ['xspath'], 'geometry': [LineString(lnst)]}
    gpd_pth = gpd.GeoDataFrame(d, crs=crs)
    # print(gpd_pth)
    # gpd_pth.set_crs(epsg=4326, inplace=True)
    gpd_pth.to_crs(epsg=3857, inplace=True)
    # print(gpd_pth)
    xs = PathGen(path_geom=gpd_pth, ny=numpts)
    xs_line = xs.get_xs()
    # print(xs_line.head())
    # print(xs_line.total_bounds, xs_line.bounds)
    bb = xs_line.total_bounds - ((100., 100., -100., -100.))
    # print('before dem', bb)
    dem = py3dep.get_map("DEM", tuple(bb), resolution=res,
                         geo_crs="EPSG:3857", crs="epsg:3857")

    # print('after dem')
    x, y = xs.get_xs_points()
    dsi = dem.interp(x=('z', x), y=('z', y))
    x1 = dsi.coords['x'].values - dsi.coords['x'].values[0]
    y1 = dsi.coords['y'].values - dsi.coords['y'].values[0]
    dist = np.hypot(x1, y1)
    pdsi = dsi.to_dataframe()
    pdsi['distance'] = dist

    # gpdsi = gpd.GeoDataFrame(pdsi, gpd.points_from_xy(pdsi.x.values, pdsi.y.values))
    gpdsi = dataframe_to_geodataframe(pdsi, crs='epsg:3857')
    # gpdsi.set_crs(epsg=3857, inplace=True)
    gpdsi.to_crs(epsg=4326, inplace=True)
    if(file):
        if not isinstance(file, str):
            # with open(file, "w") as f:
            file.write(gpdsi.to_json())
            file.close()
            return 0
        else:
            with open(file, "w") as f:
                f.write(gpdsi.to_json())
                f.close()
        # gpdsi.to_file(file, driver="GeoJSON")
            return 0
    else:
        return gpdsi


def getXSAtPoint(point, numpoints, width, file=None, res=10):
    """[summary]

    Args:
        point ([type]): [description]
        numpoints ([type]): [description]
        width ([type]): [description]
        file ([type], optional): [description]. Defaults to None.

    Returns:
        [type]: [description]
    """

    # tpoint = f'POINT({point[1]} {point[0]})'
    df = pd.DataFrame({'pointofinterest': ['this'],
                       'Lat': [point[1]],
                       'Lon': [point[0]]})
    gpd_pt = gpd.GeoDataFrame(df, geometry=gpd.points_from_xy(df.Lon, df.Lat))
    gpd_pt.set_crs(epsg=4326, inplace=True)
    gpd_pt.to_crs(epsg=3857, inplace=True)
    comid = getCIDFromLatLon(point)
    # print(f'comid = {comid}')
    strm_seg = NLDI().getfeature_byid("comid", comid).to_crs('epsg:3857')
    xs = XSGen(point=gpd_pt, cl_geom=strm_seg, ny=numpoints, width=width)
    xs_line = xs.get_xs()
    # print(comid, xs_line)
    # get topo polygon with buffer to ensure there is enough topography to interpolate xs line
    # With coarsest DEM (30m) 100. m should
    bb = xs_line.total_bounds - ((100., 100., -100., -100.))
    dem = py3dep.get_map("DEM", tuple(bb), resolution=res,
                         geo_crs="EPSG:3857", crs="epsg:3857")
    x, y = xs.get_xs_points()
    dsi = dem.interp(x=('z', x), y=('z', y))
    x1 = dsi.coords['x'].values - dsi.coords['x'].values[0]
    y1 = dsi.coords['y'].values - dsi.coords['y'].values[0]
    dist = np.hypot(x1, y1)
    pdsi = dsi.to_dataframe()
    pdsi['distance'] = dist

    # gpdsi = gpd.GeoDataFrame(pdsi, gpd.points_from_xy(pdsi.x.values, pdsi.y.values))
    gpdsi = dataframe_to_geodataframe(pdsi, crs='epsg:3857')
    # gpdsi.set_crs(epsg=3857, inplace=True)
    gpdsi.to_crs(epsg=4326, inplace=True)
    if(file):
        if not isinstance(file, str):
            # with open(file, "w") as f:
            file.write(gpdsi.to_json())
            file.close()
            return 0
        else:
            with open(file, "w") as f:
                f.write(gpdsi.to_json())
                f.close()
        # gpdsi.to_file(file, driver="GeoJSON")
            return 0
    else:
        return gpdsi


def lonlatToPoint(lon, lat):
    return Point(lon, lat)


def getCIDFromLatLon(point):
    # print(point)
    pt = lonlatToPoint(point[0], point[1])
    location = pt.wkt
    location = f'POINT({point[0]} {point[1]})'
    baseURL = 'https://labs.waterdata.usgs.gov/api/nldi/linked-data/comid/position?f=json&coords='
    url = baseURL+location
    # print(url)
    response = requests.get(url)
    jres = response.json()
    comid = jres['features'][0]['properties']['comid']
    return comid



'''
    File name: dem_query.py
    Author: Anders Hopkins, Richard McDonald
'''


import requests
# import json
from shapely.geometry import Point, LineString, Polygon

# Resolution types and their respective IDs for the Rest Service
res_types = {'res_1m': 18, 'res_3m': 19, 'res_5m': 20, 'res_10m': 21, 'res_30m': 22, 'res_60m': 23}
# res_types = {'res_1m': 1, 'res_3m': 2, 'res_5m': 3, 'res_10m': 4, 'res_30m': 5, 'res_60m': 6}
dim_order = {'latlon': 0, 'lonlat': 1}
# Create a bounding box from any geo type
# 'width' is in meters. It is the width of the buffer to place around the input geometry


def make_bbox(shape_type, coords, width):
    if shape_type == 'point':
        shape = Point(coords)

    elif shape_type == 'line':
        shape = LineString(coords)

    elif shape_type == 'polygon':
        shape = Polygon(coords)

    converted_width = convert_width(width)
    buff_shape = shape.buffer(converted_width)
    return buff_shape.bounds

# Convert the width of the buffer from meters to 'degree'
# This is NOT a precise conversion, just a quick overestimation
# Maybe fix this later


def convert_width(width):
    factor = 1/70000
    dist = factor*width
    return dist

# Get request from arcgis Rest Services


def get_dem(bbox, res_type):
    minx = str(bbox[0])
    miny = str(bbox[1])
    maxx = str(bbox[2])
    maxy = str(bbox[3])
    res_id = res_types[res_type]

    url = f'https://index.nationalmap.gov/arcgis/rest/services/3DEPElevationIndex/MapServer/{res_id}/query'
    payload = {
        # "where": "",
        # "text": "",
        # "objectIds": "",
        # "time": "",
        "geometry": "{xmin:\""+minx+"\",ymin:\""+miny+"\",xmax:\""+maxx+"\",ymax:\""+maxy+"\",spatialReference:{wkid:4326}}",
        "geometryType": "esriGeometryEnvelope",
        "inSR": "EPSG:4326",
        "spatialRel": "esriSpatialRelIntersects",
        # "relationParam": "",
        # "outFields": "",
        "returnGeometry": "true",
        # "returnTrueCurves": "false",
        "maxAllowableOffset": "100",
        "geometryPrecision": "3",
        "outSR": "EPSG:4326",
        # "having": "",
        # "returnIdsOnly": "false",
        # "returnCountOnly": "false",
        # "orderByFields": "",
        # "groupByFieldsForStatistics": "",
        # "outStatistics": "",
        # "returnZ": "false",
        # "returnM": "false",
        # "gdbVersion": "",
        # "historicMoment": "",
        # "returnDistinctValues": "false",
        # "resultOffset": "",
        # "resultRecordCount": "",
        # "queryByDistance": "",
        # "returnExtentOnly": "false",
        # "datumTransformation": "",
        # "parameterValues": "",
        # "rangeValues": "",
        # "quantizationParameters": "",
        "featureEncoding": "esriDefault",
        "f": "geojson"
        }

    r = requests.get(url, params=payload)
    resp = r.json()

    # If the Rest Services has a 200 response
    if 'features' in resp:
        # If the features are not empty, then the DEM exist
        if resp['features'] != []:
            return True
        # If features are empty, then no DEM
        if resp['features'] == []:
            return False
    # If 'error', then there was an unsuccessful request
    if 'error' in resp:
        return 'Error!'

# The function to loop thru all resolutions and submit queries


def query_dems(shape_type, coords, width=100):
    """
    Queries 3DEP 3DEPElevationIndex and returns of dictionary of available
    resolutions for shapes bounding box.

    Args:
        shape_type (Shapely geometric object in [Point, LineString, Polygon]): [description]
        coords (List of tuples): For example, [(x,y), (x,y)]
        width (int, optional): [width to buffer bounding box of shape]. Defaults to 100.
    """
    resp = {}  # Create an empty dictionary for the response
    bbox = make_bbox(shape_type, coords, width)  # Make the bbox
    print(bbox)
    for res_type in res_types:   # Loop thru all resolutions and submit a query for each one
        resp[res_type] = (get_dem(bbox, res_type))  # Add the response to the dictionary

    # print(resp)
    return(resp)


def query_dems_shape(bbox):
    resp = {}

    for res_type in res_types:
        resp[res_type] = (get_dem(bbox, res_type))
    return resp

# Tests #########
# query_dems('point', [(-96, 39)])
# query_dems('line', [(-96.0001, 39), (-96, 39)])
# query_dems('polygon', [(-96.0008, 39), (-96, 39), ( -96, 39.0008)])



#!/usr/bin/env python

"""Tests for `nldi_el_serv` package."""

import pytest

from click.testing import CliRunner

# from nldi_el_serv import nldi_el_serv
from nldi_el_serv import cli
from tempfile import NamedTemporaryFile
import json


# @pytest.fixture
# def response():
#     """Sample pytest fixture.

#     See more at: http://doc.pytest.org/en/latest/fixture.html
#     """
#     # import requests
#     # return requests.get('https://github.com/audreyr/cookiecutter-pypackage')


# def test_content(response):
#     """Sample pytest test function with the pytest fixture as an argument."""
#     # from bs4 import BeautifulSoup
#     # assert 'GitHub' in BeautifulSoup(response.content).title.string


def test_command_line_interface():
    """Test the CLI."""
    runner = CliRunner()
    result = runner.invoke(cli.main)
    print(result)
    assert result.exit_code == 0
    assert 'xsatpoint' in result.output
    help_result = runner.invoke(cli.main, ['--help'])
    assert help_result.exit_code == 0
    assert '\n\nCommands:\n  xsatendpts\n' in help_result.output


def test_xsatpoint():
    runner = CliRunner()

    with NamedTemporaryFile(mode='w+') as tf:
        result = runner.invoke(
                                cli.main,
                                [
                                    'xsatpoint', '-f', tf.name,
                                    '--lonlat', '-103.80119', '40.2684',
                                    '--width', '100', '--numpoints', '11',
                                    '-r', '10m'
                                ]
                              )
        assert(result.exit_code == 0)
        ogdata = json.load(tf)
        feat = ogdata.get('features')
        assert(len(feat) == 11)


def test_xsatendpts():
    runner = CliRunner()

    with NamedTemporaryFile(mode='w+') as tf:
        result = runner.invoke(
                                cli.main,
                                [
                                    'xsatendpts', '-f', tf.name,
                                    '-s', '-103.801134', '40.26733',
                                    '-e', '-103.800787', ' 40.272798',
                                    '-c', 'epsg:4326',
                                    '-n', '11',
                                    '-r', '10m'
                                ]
                              )
        assert(result.exit_code == 0)
        ogdata = json.load(tf)
        feat = ogdata.get('features')
        assert(len(feat) == 11)


def test_xsatendpts_wres():
    runner = CliRunner()
    res = ['1m', '3m', '5m', '10m', '30m']
    for tr in res:
        print(f'resoluition: {tr}')
        with NamedTemporaryFile(mode='w+') as tf:
            result = runner.invoke(
                                    cli.main,
                                    [
                                        'xsatendpts', '-f', tf.name,
                                        '-s', '-103.801134', '40.26733',
                                        '-e', '-103.800787', ' 40.272798',
                                        '-c', 'epsg:4326',
                                        '-n', '11',
                                        '-r', tr
                                    ]
                                )
            assert(result.exit_code == 0)
            ogdata = json.load(tf)
            feat = ogdata.get('features')
            assert(len(feat) == 11)



#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

# with open('requires.txt') as f:
#     requirements = f.read().splitlines()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=7.0',
                'pygeohydro==0.10.2',
                'py3dep==0.10.1',
                'pygeoogc==0.10.1',
                'pygeoutils==0.10.1',
                'pynhd==0.10.1',
                'dataretrieval==0.7',
                'folium==0.0.0',
                'lxml==4.6.3',
                'matplotlib==3.4.1',
                'xarray==0.17.0',
                'scipy==1.6.2',
                'dask==2021.4.0',
                'netcdf4==1.5.6',
                'bottleneck==1.3.2',
                'jupyterlab==3.0.14',
                'geopandas==0.9.0',
                'descartes==1.1.0',
                'numba==0.53.1']

setup_requirements = ['pytest-runner', ]

test_requirements = ['pytest>=3', ]

setup(
    author="Richard McDonald",
    author_email='rmcd@usgs.gov',
    python_requires='>=3.8',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: CC0 1.0 Universal (CC0 1.0) Public Domain Dedication',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.8',
    ],
    description="NLDI Elevation Services",
    entry_points={
        'console_scripts': [
            'nldi_el_serv=nldi_el_serv.cli:main',
        ],
    },
    install_requires=requirements,
    license="CC0 1.0 Universal public domain dedication",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='nldi_el_serv',
    name='nldi_el_serv',
    packages=find_packages(include=['nldi_el_serv', 'nldi_el_serv.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/ACWI-SSWD/nldi_el_serv',
    version='0.1.4',
    zip_safe=False,
)
